﻿// ***********************************************************************
// Provided for Informational Purposes Only
//
// Apache 2.0 License
//
// Licensed under the Apache License, Version 2.0 (the "License"); you may
// not use this file except in compliance with the License. You may obtain
// a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 
//
// THIS CODE IS PROVIDED *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
// ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY 
// IMPLIED WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR 
// PURPOSE, MERCHANTABLITY OR NON-INFRINGEMENT.
//
// See the Apache Version 2.0 License for specific language governing
// permissions and limitations under the License.
// ***********************************************************************
// Assembly  : ContractMeow.Api.WinRT
// File      : IUserClient.cs
//
// ***********************************************************************
using ContractMeow.Api.Dtos;
using ContractMeow.Api.Dtos.User;
using System;
using System.Threading.Tasks;

namespace ContractMeow.Api.Clients
{
	/// <summary>
	/// Interface for making user info calls to the API (specifies the contract of an user client)
	/// </summary>
	public interface IUserClient : IApiClient
	{
		/// <summary>
		/// Gets the current user profile information.
		/// </summary>
		/// <param name="principal">The principal.</param>
		/// <param name="requestParameters">The request parameters.</param>
		/// <returns>Task{User}.</returns>
		Task<User> GetCurrentUserAsync(Dtos.Principal principal, UserRequestParameters requestParameters = null);

		/// <summary>
		/// Gets the user's profile info by id.
		/// </summary>
		/// <param name="principal">The principal.</param>
		/// <param name="id">The id.</param>
		/// <returns>Task{User}.</returns>
		Task<User> GetUserByIdAsync(Dtos.Principal principal, Int64 id);
	}
}