﻿// ***********************************************************************
// Provided for Informational Purposes Only
//
// Apache 2.0 License
//
// Licensed under the Apache License, Version 2.0 (the "License"); you may
// not use this file except in compliance with the License. You may obtain
// a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 
//
// THIS CODE IS PROVIDED *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
// ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY 
// IMPLIED WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR 
// PURPOSE, MERCHANTABLITY OR NON-INFRINGEMENT.
//
// See the Apache Version 2.0 License for specific language governing
// permissions and limitations under the License.
// ***********************************************************************
// Assembly  : ContractMeow.Api.WinRT
// File      : ErrorToExceptionTranslator.cs
//
// ***********************************************************************
using ContractMeow.Api.Dtos;
using ContractMeow.Api.Exceptions;
using System;
using System.Net;

namespace ContractMeow.Api
{
	/// <summary>
	/// Translates YammerApi error bodies (mostly 401) into more granular exceptions
	/// </summary>
	public class ErrorToExceptionTranslator : IErrorToExceptionTranslator
	{
		//These codes hang out in api_messages.yml
		/// <summary>
		/// Translates the specified status.
		/// </summary>
		/// <param name="status">The status.</param>
		/// <param name="error">The error.</param>
		/// <returns>Exception.</returns>
		public Exception Translate(HttpStatusCode status, Error error)
		{
			switch (error.Code)
			{
				case 4:
					// user account deactivated.. log them out
					// TODO: this should show them a message to explain WHY
					return new AccountDeactivatedException();
				case 16:
					return new TokenNotFoundException();
				case 17:
					return new ForbiddenException();
				case 32:
				case 33:
					return new RateLimitExceededException();
				default:
					return null;
			}
		}
	}
}