﻿// ***********************************************************************
// Provided for Informational Purposes Only
//
// Apache 2.0 License
//
// Licensed under the Apache License, Version 2.0 (the "License"); you may
// not use this file except in compliance with the License. You may obtain
// a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 
//
// THIS CODE IS PROVIDED *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
// ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY 
// IMPLIED WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR 
// PURPOSE, MERCHANTABLITY OR NON-INFRINGEMENT.
//
// See the Apache Version 2.0 License for specific language governing
// permissions and limitations under the License.
// ***********************************************************************
// Assembly  : ContractMeow.Api.WinRT
// File      : HttpResponseHandler.cs
//
// ***********************************************************************
using ContractMeow.Api.Dtos;
using ContractMeow.WinRT.Serialization;
using System;
using System.Net.Http;
using System.Threading.Tasks;

namespace ContractMeow.Api.Net
{
	public class HttpResponseHandler
	{
		private readonly IDeserializer _deserializer;
		private readonly IResponseErrorHandler _responseErrorHandler;

		public HttpResponseHandler(IDeserializer deserializer, IResponseErrorHandler responseErrorHandler)
		{
			_deserializer = deserializer;
			_responseErrorHandler = responseErrorHandler;
		}

		public async Task<IBaseEnvelope<T>> HandleResponseAsync<T>(HttpResponseMessage response) where T : class
		{
			Exception ex = null;
			IBaseEnvelope<T> result = new BaseEnvelope<T>();

			if (!response.IsSuccessStatusCode)
			{
				//This should throw an exception for known errors.
				// no I/O or long task here, calling for result sync is cheaper
				ex = await _responseErrorHandler.HandleAsync(response);
			}
			if (ex != null)
			{
				result.Exception = ex;
			}
			else
			{
				try
				{
					// Throw a generic exception for anything other than 200.
					response.EnsureSuccessStatusCode();
				}
				catch (Exception httpEx)
				{
					ex = httpEx;
				}

				if (ex != null)
					result.Exception = ex;
				else
				{
					var content = await response.Content.ReadAsByteArrayAsync();
					result.Content = _deserializer.Deserialize<T>(content);
				}
			}

			return result;
		}

	}
}
