﻿// ***********************************************************************
// Provided for Informational Purposes Only
//
// Apache 2.0 License
//
// Licensed under the Apache License, Version 2.0 (the "License"); you may
// not use this file except in compliance with the License. You may obtain
// a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 
//
// THIS CODE IS PROVIDED *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
// ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY 
// IMPLIED WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR 
// PURPOSE, MERCHANTABLITY OR NON-INFRINGEMENT.
//
// See the Apache Version 2.0 License for specific language governing
// permissions and limitations under the License.
// ***********************************************************************
// Assembly  : ContractMeow.Api.WinRT
// File      : OAuthResponseErrorHandler.cs
//
// ***********************************************************************
using ContractMeow.Api.Exceptions;
using System;
using System.Net;
using System.Net.Http;
using System.Threading.Tasks;

namespace ContractMeow.Api
{
	/// <summary>
	/// Class OAuthResponseErrorHandler
	/// </summary>
	public class OAuthResponseErrorHandler : IResponseErrorHandler
	{

		/// <summary>
		/// Initializes a new instance of the <see cref="OAuthResponseErrorHandler" /> class.
		/// </summary>
		public OAuthResponseErrorHandler()
		{

		}

		/// <summary>
		/// Throws exceptions for known error types so they can be handled properly, if desired.
		/// </summary>
		/// <param name="response">The http response</param>
		/// <returns>Task{Exception}.</returns>
		public Task<Exception> HandleAsync(HttpResponseMessage response)
		{
			return Task.Run(() =>
				{
					Exception exception = null;

					switch (response.StatusCode)
					{
						//Currently the server will return html for 500 errors, so there's nothing useful to do.
						case HttpStatusCode.InternalServerError:
							exception = new ServerErrorException();
							break;
						case HttpStatusCode.Unauthorized:
							exception = new UnauthorizedException("401 (Unauthorized)", response.StatusCode);
							break;
						case HttpStatusCode.Forbidden:
							exception = new SSOEnabledException();
							break;
						case HttpStatusCode.GatewayTimeout:
						case HttpStatusCode.ServiceUnavailable:
						case HttpStatusCode.RequestTimeout:
							exception = new ConnectionFailureException();
							break;
					}

					return exception;
				});
		}
	}
}