﻿// ***********************************************************************
// Provided for Informational Purposes Only
//
// Apache 2.0 License
//
// Licensed under the Apache License, Version 2.0 (the "License"); you may
// not use this file except in compliance with the License. You may obtain
// a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 
//
// THIS CODE IS PROVIDED *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
// ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY 
// IMPLIED WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR 
// PURPOSE, MERCHANTABLITY OR NON-INFRINGEMENT.
//
// See the Apache Version 2.0 License for specific language governing
// permissions and limitations under the License.
// ***********************************************************************
// Assembly  : ContractMeow.Data.WinRT
// File      : BaseRepository.cs
//
// ***********************************************************************
using System;
using System.Runtime.CompilerServices;
using System.Threading.Tasks;

namespace ContractMeow.Data.WinRT.Api
{
	public abstract class BaseRepository
	{
		protected readonly IStateManager _stateManager;

		public BaseRepository(IStateManager stateManager)
		{
			this._stateManager = stateManager;
		}

		/// <summary>
		/// An asynchronous version of <see cref="Execute{T}"/>.
		/// </summary>
		/// <typeparam name="T"></typeparam>
		/// <param name="action"></param>
		/// <param name="methodName"></param>
		/// <returns></returns>
		protected Task<T> ExecuteAsync<T>(Func<T> action, [CallerMemberName] String methodName = null)
		{
			return Task.Run<T>(() => Execute(action, methodName));
		}

		/// <summary>
		/// An asynchronous version of <see cref="Execute{T}"/> which handles async actions.
		/// </summary>
		/// <typeparam name="T"></typeparam>
		/// <param name="action"></param>
		/// <param name="methodName"></param>
		/// <returns></returns>
		protected Task<T> ExecuteAsync<T>(Func<Task<T>> action, [CallerMemberName] String methodName = null)
		{
			return Execute(action, methodName);
		}

		/// <summary>
		/// Should be used to wrap individual repository methods with basic, shared exception handling.
		/// </summary>
		/// <typeparam name="T"></typeparam>
		/// <param name="action"></param>
		/// <param name="methodName"></param>
		/// <returns></returns>
		protected T Execute<T>(Func<T> action, [CallerMemberName] String methodName = null)
		{
			try
			{
				return action();
			}
			catch (Exception ex)
			{
				throw;
			}
		}
	}
}