// ***********************************************************************
// Provided for Informational Purposes Only
//
// Apache 2.0 License
//
// Licensed under the Apache License, Version 2.0 (the "License"); you may
// not use this file except in compliance with the License. You may obtain
// a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 
//
// THIS CODE IS PROVIDED *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
// ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY 
// IMPLIED WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR 
// PURPOSE, MERCHANTABLITY OR NON-INFRINGEMENT.
//
// See the Apache Version 2.0 License for specific language governing
// permissions and limitations under the License.
// ***********************************************************************
// Assembly  : ContractMeow.Data.WinRT
// File      : UsersRepository.cs
//
// ***********************************************************************
using ContractMeow.Api.Clients;
using ContractMeow.Api.Dtos.AutoComplete;
using System.Collections.Generic;
using System.Threading.Tasks;

namespace ContractMeow.Data.WinRT.Api
{
	/// <summary>
	/// Provides access to authorization and permission related things via the Yammer Api.
	/// </summary>
	public sealed class UsersRepository : BaseRepository, IUsersRepository
	{
		/// <summary>
		/// Yammer api client for doing all the actual work.
		/// </summary>
		private readonly IAutoCompleteClient _client;

		/// <summary>
		/// Initializes a new instance of the <see cref="UsersRepository" /> class.
		/// </summary>
		/// <param name="stateManager">The state manager.</param>
		/// <param name="authClient">The users client.</param>
		public UsersRepository(IStateManager stateManager, IAutoCompleteClient client)
			: base(stateManager)
		{
			this._client = client;
		}

		public async Task<IEnumerable<AutoCompleteUser>> GetUsersAsync()
		{
			var usersEnvelope = await this._client.GetUsersAutocompleteAsync(this._stateManager.Credentials, string.Empty);
			return usersEnvelope.Users;
		}
	}
}