﻿// ***********************************************************************
// Provided for Informational Purposes Only
//
// Apache 2.0 License
//
// Licensed under the Apache License, Version 2.0 (the "License"); you may
// not use this file except in compliance with the License. You may obtain
// a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 
//
// THIS CODE IS PROVIDED *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
// ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY 
// IMPLIED WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR 
// PURPOSE, MERCHANTABLITY OR NON-INFRINGEMENT.
//
// See the Apache Version 2.0 License for specific language governing
// permissions and limitations under the License.
// ***********************************************************************
// Assembly  : ContractMeow.Data.WinRT
// File      : IAuthRepository.cs
//
// ***********************************************************************
using ContractMeow.Data.WinRT.Models;
using System;
using System.Net;
using System.Threading.Tasks;

namespace ContractMeow.Data.WinRT
{
	/// <summary>
	/// Provides access to authorization and permission related things.
	/// </summary>
	public interface IAuthRepository : IRepository
	{
		/// <summary>
		/// Attempts to log the user in with the given credentials. If successful, the authorization is stored for future requests.
		/// </summary>
		/// <param name="username">The user's username</param>
		/// <param name="password">The user's password</param>
		/// <returns>The authorization credentials for the user.</returns>
		Task<Credentials> LoginAsync(String username, String password);

		Task<Credentials> HydrateCredentialsAsync(string token);

		/// <summary>
		/// Uses existing authorization from a prior login
		/// </summary>
		/// <param name="credentials">existing credentials from a prior authorization</param>
		void Login(Credentials credentials);

		/// <summary>
		/// Removes the stored user credentials, if there is one.
		/// </summary>
		void Logout();

		CookieContainer CookieContainer { get; }
	}
}