﻿// ***********************************************************************
// Provided for Informational Purposes Only
//
// Apache 2.0 License
//
// Licensed under the Apache License, Version 2.0 (the "License"); you may
// not use this file except in compliance with the License. You may obtain
// a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 
//
// THIS CODE IS PROVIDED *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
// ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY 
// IMPLIED WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR 
// PURPOSE, MERCHANTABLITY OR NON-INFRINGEMENT.
//
// See the Apache Version 2.0 License for specific language governing
// permissions and limitations under the License.
// ***********************************************************************
// Assembly  : ContractMeow.Data.WinRT
// File      : Credentials.cs
//
// ***********************************************************************
using ContractMeow.Api.Dtos;
using ContractMeow.Models;
using System;

namespace ContractMeow.Data.WinRT.Models
{
	/// <summary>
	/// Class Credentials
	/// </summary>
	public sealed class Credentials
	{
		public Credentials() { }

		internal Credentials(Principal principal)
		{
			UserId = principal.UserId;
			NetworkId = principal.NetworkId;
			AuthToken = new Token
			{
				AuthenticatedAt = principal.AuthorizedAt,
				ExpiresAt = principal.ExpiresAt,
				Key = principal.AccessToken
			};
		}

		public long Id
		{
			get { return UserId; }
		}

		public Int64 UserId { get; set; }

		public Int64 NetworkId { get; set; }

		public Token AuthToken { get; set; }


		public static implicit operator Principal(Credentials credentials)
		{
			return new Principal()
			{
				UserId = credentials.UserId,
				NetworkId = credentials.NetworkId,
				AccessToken = credentials.AuthToken.Key,
				AuthorizedAt = credentials.AuthToken.AuthenticatedAt,
				ExpiresAt = credentials.AuthToken.ExpiresAt
			};
		}

		public static explicit operator Credentials(Principal principal)
		{
			return new Credentials(principal);
		}
	}
}
