﻿// ***********************************************************************
// Provided for Informational Purposes Only
//
// Apache 2.0 License
//
// Licensed under the Apache License, Version 2.0 (the "License"); you may
// not use this file except in compliance with the License. You may obtain
// a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 
//
// THIS CODE IS PROVIDED *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
// ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY 
// IMPLIED WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR 
// PURPOSE, MERCHANTABLITY OR NON-INFRINGEMENT.
//
// See the Apache Version 2.0 License for specific language governing
// permissions and limitations under the License.
// ***********************************************************************
// Assembly  : ContractMeow.WinRT
// File      : NoopDeserializer.cs
//
// ***********************************************************************
using Newtonsoft.Json;
using System;
using System.Text;

namespace ContractMeow.WinRT.Serialization
{
	/// <summary>
	/// Class NoopDeserializer
	/// </summary>
	public class NoopDeserializer : IDeserializer
	{
		/// <summary>
		/// Gets the text encoding.
		/// </summary>
		/// <value>The text encoding.</value>
		public Encoding TextEncoding
		{
			get { return Encoding.UTF8; }
		}

		public JsonSerializerSettings DeserializerSettings { get; private set; }

		public NoopDeserializer()
		{
			DeserializerSettings = new JsonSerializerSettings() { NullValueHandling = NullValueHandling.Ignore };

		}
		/// <summary>
		/// Deserializes the async.
		/// </summary>
		/// <typeparam name="T"></typeparam>
		/// <param name="content">The content.</param>
		/// <returns>A default object of type <see cref="T"/></returns>
		public T Deserialize<T>(Byte[] content)
		{
			return default(T);
		}

		/// <summary>
		/// Deserializes the async.
		/// </summary>
		/// <typeparam name="T"></typeparam>
		/// <param name="content">The content.</param>
		/// <returns>A default object of type <see cref="T"/></returns>
		public T Deserialize<T>(String content)
		{
			return default(T);
		}
	}
}