﻿// ***********************************************************************
// Apache 2.0 License
// Licensed under the Apache License, Version 2.0 (the "License"); you may
// not use this file except in compliance with the License. You may obtain
// a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 
//
// THIS CODE IS PROVIDED *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
// ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY 
// IMPLIED WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR 
// PURPOSE, MERCHANTABLITY OR NON-INFRINGEMENT.
//
// See the Apache Version 2.0 License for specific language governing
// permissions and limitations under the License.
// ***********************************************************************
// Assembly  : ContractMeow.Api.Dtos
// File      : BaseEnvelope.cs
//
// ***********************************************************************

namespace ContractMeow.Api.Dtos
{
	/// <summary>
	/// Class BaseEnvelope
	/// </summary>
	/// <typeparam name="T"></typeparam>
	public class BaseEnvelope<T> : IBaseEnvelope<T>
	{
		/// <summary>
		/// Gets or sets the content.
		/// </summary>
		/// <value>The content.</value>
		public T Content { get; set; }

		/// <summary>
		/// Gets or sets the exception.
		/// </summary>
		/// <value>The exception.</value>
		public System.Exception Exception { get; set; }

		/// <summary>
		/// Gets a value indicating whether this instance is faulted.
		/// </summary>
		/// <value><c>true</c> if this instance is faulted; otherwise, <c>false</c>.</value>
		public bool IsFaulted
		{
			get { return Exception != null; }
		}

		/// <summary>
		/// Returns the result if not faulted, otherwise it throws the encapsulated exception.
		/// </summary>
		/// <returns>Content</returns>
		public T Result()
		{
			if (IsFaulted)
				throw Exception;
			return Content;
		}
	}
}
