﻿// ***********************************************************************
// Apache 2.0 License
// Licensed under the Apache License, Version 2.0 (the "License"); you may
// not use this file except in compliance with the License. You may obtain
// a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 
//
// THIS CODE IS PROVIDED *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
// ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY 
// IMPLIED WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR 
// PURPOSE, MERCHANTABLITY OR NON-INFRINGEMENT.
//
// See the Apache Version 2.0 License for specific language governing
// permissions and limitations under the License.
// ***********************************************************************
// Assembly  : ContractMeow.Api.Dtos
// File      : MessageEnvelope.cs
//
// ***********************************************************************

using ContractMeow.Api.Dtos.References;
using ContractMeow.Api.Dtos.Serialization;
using Newtonsoft.Json;

namespace ContractMeow.Api.Dtos
{
	/// <summary>
	/// Message API response that contains a list of messages (thread starters),
	/// a list of references, meta object (perspective data), and, optionally, a collection of messages for each thread.
	/// </summary>
	public sealed class MessageEnvelope
	{
		/// <summary>
		/// Gets or sets the messages.
		/// </summary>
		/// <value>The messages.</value>
		[JsonProperty("messages")]
		public Message.Message[] Messages { get; set; }
		/// <summary>
		/// Gets or sets the references.
		/// </summary>
		/// <value>The references.</value>
		[JsonProperty("references")]
		[JsonConverter(typeof(ReferenceJsonConverter))]
		public IReference[] References { get; set; }
		/// <summary>
		/// Gets or sets the meta.
		/// </summary>
		/// <value>The meta.</value>
		[JsonProperty("meta")]
		public Meta Meta { get; set; }
		/// <summary>
		/// Gets or sets the thread messages.
		/// </summary>
		/// <value>The thread messages.</value>
		[JsonProperty("threaded_extended")]
		public ThreadMessagesDictionary ThreadMessages { get; set; }
	}
}
