﻿// ***********************************************************************
// Apache 2.0 License
// Licensed under the Apache License, Version 2.0 (the "License"); you may
// not use this file except in compliance with the License. You may obtain
// a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 
//
// THIS CODE IS PROVIDED *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
// ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY 
// IMPLIED WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR 
// PURPOSE, MERCHANTABLITY OR NON-INFRINGEMENT.
//
// See the Apache Version 2.0 License for specific language governing
// permissions and limitations under the License.
// ***********************************************************************
// Assembly  : ContractMeow.Api.Dtos
// File      : GroupReference.cs
//
// ***********************************************************************
using ContractMeow.Api.Dtos.Serialization;
using Newtonsoft.Json;
using System;

namespace ContractMeow.Api.Dtos.References
{
	public sealed class GroupReference : IReference
	{
		public const String ApiType = "group";

		[JsonProperty("id")]
		public Int64 Id { get; set; }
		[JsonProperty("created_at")]
		public DateTimeOffset? CreatedAt { get; set; }
		[JsonProperty("name")]
		public String Name { get; set; }
		[JsonProperty("full_name")]
		public String FullName { get; set; }
		[JsonProperty("description")]
		public String Description { get; set; }
		[JsonProperty("privacy")]
		[JsonConverter(typeof(PrivacyJsonConverter))]
		public Boolean IsPublic { get; set; }

		/// <summary>
		/// Example: https://mug0.staging.assets-Yammer.com/mugshot/images/{width}x{height}/8rSw98rgTjnTlS2QXk0wVq9kCPzggRp2
		/// </summary>
		[JsonProperty("mugshot_url_template")]
		public String MugshotUrlTemplate { get; set; }
		[JsonProperty("mugshot_url")]
		public Uri MugshotUrl { get; set; }
		[JsonProperty("web_url")]
		public Uri WebUrl { get; set; }
		[JsonProperty("url")]
		public Uri Url { get; set; }

		[JsonProperty("type")]
		public String Type { get { return ApiType; } }

		[JsonIgnore]
		public String DisplayValue { get { return FullName; } }
	}
}
