﻿// ***********************************************************************
// Apache 2.0 License
// Licensed under the Apache License, Version 2.0 (the "License"); you may
// not use this file except in compliance with the License. You may obtain
// a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 
//
// THIS CODE IS PROVIDED *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
// ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY 
// IMPLIED WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR 
// PURPOSE, MERCHANTABLITY OR NON-INFRINGEMENT.
//
// See the Apache Version 2.0 License for specific language governing
// permissions and limitations under the License.
// ***********************************************************************
// Assembly  : ContractMeow.Api.Dtos
// File      : IDeserializer.cs
//
// ***********************************************************************
using Newtonsoft.Json;
using System.Text;

namespace ContractMeow.Api.Dtos.Serialization
{
	/// <summary>
	/// Interface IDeserializer
	/// </summary>
	public interface IDeserializer
	{
		/// <summary>
		/// Gets the text encoding.
		/// </summary>
		/// <value>The text encoding.</value>
		Encoding TextEncoding { get; }

		/// <summary>
		/// Gets the deserializer settings.
		/// </summary>
		/// <value>The deserializer settings.</value>
		JsonSerializerSettings DeserializerSettings { get; }

		/// <summary>
		/// Deserializes the async.
		/// </summary>
		/// <typeparam name="T"></typeparam>
		/// <param name="content">The content.</param>
		/// <returns>Task{``0}.</returns>
		T Deserialize<T>(byte[] content);

		/// <summary>
		/// Deserializes the async.
		/// </summary>
		/// <typeparam name="T"></typeparam>
		/// <param name="content">The content.</param>
		/// <returns>Task{``0}.</returns>
		T Deserialize<T>(string content);
	}
}