﻿// ***********************************************************************
// Apache 2.0 License
// Licensed under the Apache License, Version 2.0 (the "License"); you may
// not use this file except in compliance with the License. You may obtain
// a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 
//
// THIS CODE IS PROVIDED *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
// ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY 
// IMPLIED WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR 
// PURPOSE, MERCHANTABLITY OR NON-INFRINGEMENT.
//
// See the Apache Version 2.0 License for specific language governing
// permissions and limitations under the License.
// ***********************************************************************
// Assembly  : ContractMeow.Api.Dtos
// File      : ReferenceJsonConverter.cs
//
// ***********************************************************************
using ContractMeow.Api.Dtos.References;
using Newtonsoft.Json;
using Newtonsoft.Json.Linq;
using System;
using System.Collections.Generic;
using System.Linq;

namespace ContractMeow.Api.Dtos.Serialization
{
	internal class ReferenceJsonConverter : JsonConverter
	{
		public override Boolean CanRead { get { return true; } }
		public override Boolean CanWrite { get { return false; } }
		public override Boolean CanConvert(Type objectType)
		{
			return objectType == typeof(IReference[])
				   || objectType == typeof(IList<IReference>);
		}

		private static readonly Dictionary<String, Type> TypeMap = new Dictionary<String, Type> {
			//User types
			{ "user", typeof(UserReference) },
			{ "guide", typeof(UserReference) },
			{ "bot", typeof(UserReference) },
			//Other references
			{ "conversation", typeof(ConversationReference) },
			{ "message", typeof(MessageReference) },
			{ "thread", typeof(ThreadReference) },
			{ "shared_thread", typeof(SharedThreadReference) },
			{ "group", typeof(GroupReference) },
			{ "tag", typeof(TagReference) },
			{ "topic", typeof(TopicReference) }
		};

		public override object ReadJson(JsonReader reader, Type objectType, object existingValue, JsonSerializer serializer)
		{
			return JArray.Load(reader)
				.Where(item => TypeMap.ContainsKey(item["type"].ToString()))
				.Select(item => (IReference)serializer.Deserialize(item.CreateReader(), TypeMap[item["type"].ToString()]))
				.ToArray();
		}

		public override void WriteJson(JsonWriter writer, object value, JsonSerializer serializer)
		{
			throw new NotImplementedException("This converter cannot write.");
		}
	}
}