﻿// ***********************************************************************
// Apache 2.0 License
// Licensed under the Apache License, Version 2.0 (the "License"); you may
// not use this file except in compliance with the License. You may obtain
// a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 
//
// THIS CODE IS PROVIDED *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
// ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY 
// IMPLIED WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR 
// PURPOSE, MERCHANTABLITY OR NON-INFRINGEMENT.
//
// See the Apache Version 2.0 License for specific language governing
// permissions and limitations under the License.
// ***********************************************************************
// Assembly  : ContractMeow.Api.Dtos
// File      : ThreadEnvelope.cs
//
// ***********************************************************************
using ContractMeow.Api.Dtos.References;
using ContractMeow.Api.Dtos.Serialization;
using Newtonsoft.Json;
using System;

namespace ContractMeow.Api.Dtos
{
	/// <summary>
	/// Returns thread related information. Response from /api/v1/threads/[thread_id].json end point.
	/// </summary>
	public sealed class ThreadEnvelope
	{
		[JsonProperty("id")]
		public Int64 Id { get; set; }
		[JsonProperty("type")]
		public String Type { get { return "thread"; } }
		[JsonProperty("thread_starter_id")]
		public Int64 ThreadStarterId { get; set; }
		[JsonProperty("has_attachments")]
		public Boolean HasAttachments { get; set; }
		[JsonProperty("privacy")]
		[JsonConverter(typeof(PrivacyJsonConverter))]
		public Boolean IsPublic { get; set; }
		[JsonProperty("web_url")]
		public Uri WebUrl { get; set; }
		[JsonProperty("url")]
		public Uri Url { get; set; }
		[JsonProperty("direct_message")]
		public Boolean IsDirectMessage { get; set; }
		[JsonProperty("references")]
		[JsonConverter(typeof(ReferenceJsonConverter))]
		public IReference[] References { get; set; }
		[JsonProperty("stats")]
		public ThreadStats Stats { get; set; }
		[JsonProperty("topics")]
		public TopicLink[] Topics { get; set; }
		//todo: attachments
	}
}
