﻿// ***********************************************************************
// Apache 2.0 License
// Licensed under the Apache License, Version 2.0 (the "License"); you may
// not use this file except in compliance with the License. You may obtain
// a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 
//
// THIS CODE IS PROVIDED *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
// ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY 
// IMPLIED WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR 
// PURPOSE, MERCHANTABLITY OR NON-INFRINGEMENT.
//
// See the Apache Version 2.0 License for specific language governing
// permissions and limitations under the License.
// ***********************************************************************
// Assembly  : ContractMeow.Models
// File      : IAttachmentModel.cs
//
// ***********************************************************************

using System;

namespace ContractMeow.Models.Attachments
{
	/// <summary>
	/// Interface IAttachmentModel
	/// </summary>
	public interface IAttachmentModel : IMessageComponent
	{
		/// <summary>
		/// Gets or sets the id.
		/// </summary>
		/// <value>The id.</value>
		long Id { get; set; }

		/// <summary>
		/// Gets or sets the created at.
		/// </summary>
		/// <value>The created at.</value>
		DateTimeOffset? CreatedAt { get; set; }

		/// <summary>
		/// Gets or sets the group id.
		/// </summary>
		/// <value>The group id.</value>
		Int64? GroupId { get; set; }

		/// <summary>
		/// Gets or sets the size.
		/// </summary>
		/// <value>The size.</value>
		long Size { get; set; }

		/// <summary>
		/// Gets the Attachment type.
		/// </summary>
		/// <value>The type.</value>
		AttachmentType Type { get; }

		/// <summary>
		/// Gets or sets the URL.
		/// </summary>
		/// <value>The URL.</value>
		Uri Url { get; set; }

		/// <summary>
		/// Gets or sets the web URL.
		/// Note: this should be a Uri, however, if someone adds a link to a post that's not a valid Uri this would blow up.
		/// So, start as a string and validate later if you want to use it.
		/// </summary>
		/// <value>The web URL.</value>
		Uri WebUrl { get; set; }
		String Name { get; set; }
		String Description { get; set; }
		bool HasName { get; }
		bool HasDescription { get; }
		bool HasHostDomain { get; }
	}
}
