﻿// ***********************************************************************
// Provided for Informational Purposes Only
//
// Apache 2.0 License
//
// Licensed under the Apache License, Version 2.0 (the "License"); you may
// not use this file except in compliance with the License. You may obtain
// a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 
//
// THIS CODE IS PROVIDED *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
// ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY 
// IMPLIED WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR 
// PURPOSE, MERCHANTABLITY OR NON-INFRINGEMENT.
//
// See the Apache Version 2.0 License for specific language governing
// permissions and limitations under the License.
// ***********************************************************************
// Assembly  : ContractMeow.Models
// File      : Network.cs
//
// ***********************************************************************
using System;
using System.Collections.Generic;
using System.Linq;

using Representations = ContractMeow.Api.Dtos;

namespace ContractMeow.Models
{
	public sealed class Network
	{
		internal Network() { }

		internal Network(Representations.Network network)
		{
			if (network == null)
			{
				return;
			}

			this.Id = network.Id;
			this.Name = network.Name;
			this.WebUrl = network.WebUrl;
			this.GroupCounts = new GroupCounts(network.GroupCounts);
		}

		public Int64 Id { get; set; }

		public String Name { get; set; }

		public Uri WebUrl { get; set; }

		public GroupCounts GroupCounts { get; private set; }
	}

	public class GroupCount
	{
		public long Id { get; set; }
		public int UnreadCount { get; set; }
	}

	public class GroupCounts
	{
		public GroupCounts(Representations.GroupCounts groupCounts)
		{
			if (groupCounts == null)
				return;

			UnseenGeneralThreadCount = groupCounts.UnseenGeneralThreadCount;
			UnreadCounts = groupCounts.UnseenGroupThreadCounts.Select(pair => new GroupCount { Id = pair.Key, UnreadCount = pair.Value }).ToList();
		}

		public int UnseenGeneralThreadCount { get; private set; }
		public IEnumerable<GroupCount> UnreadCounts { get; private set; }
	}
}