﻿// ***********************************************************************
// Provided for Informational Purposes Only
//
// Apache 2.0 License
//
// Licensed under the Apache License, Version 2.0 (the "License"); you may
// not use this file except in compliance with the License. You may obtain
// a copy of the License at http://www.apache.org/licenses/LICENSE-2.0 
//
// THIS CODE IS PROVIDED *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
// ANY KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY 
// IMPLIED WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR 
// PURPOSE, MERCHANTABLITY OR NON-INFRINGEMENT.
//
// See the Apache Version 2.0 License for specific language governing
// permissions and limitations under the License.
// ***********************************************************************
// Assembly  : ContractMeow.Models
// File      : TreatmentType.cs
//
// ***********************************************************************
using ContractMeow.Api.Dtos.Attribute.Generic;
using ContractMeow.Api.Dtos.Attributes;

namespace ContractMeow.Models
{
	/// <summary>
	/// The known treatments (potentially backed by the api). The names of these treatments (not their integer value) should be immutable.
	/// </summary>
	public enum TreatmentType : int
	{
		[Hidden(true)]
		UnitTestEnabledOffEditableOff,

		[Hidden(true)]
		[DefaultEnabled(true)]
		UnitTestEnabledOnEditableOff,

		[Hidden(true)]
		[Editable(true)]
		UnitTestEnabledOffEditableOn,

		[Hidden(true)]
		[DefaultEnabled(true)]
		[Editable(true)]
		UnitTestEnabledOnEditableOn,

		[Description("Enables the new Fancy Publisher")]
		//[ApiKey("prototype_publisher")]
		[DefaultEnabled(true)]
		[Editable(true)]
		PublisherFancy,

		[Description("Enables the Group Menu on FeedView")]
		[DefaultEnabled(false)]
		[Editable(true)]
		FeedViewGroupMenuVisible,

		[Description("Enable file uploading on Publisher")]
		[DefaultEnabled(false)]
		[Editable(true)]
		EnableFileUpload,
	}
}